currencydelegate — Camelot documentation

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- controls »
- delegates »

# currencydelegate

class `camelot.view.controls.delegates.currencydelegate.` `CurrencyDelegate`(minimum=-1000000000000000.0, maximum=1000000000000000.0, parent=None, unicode_format=None, **kwargs)

  Custom delegate for currency values

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- controls »
- delegates »

Comments
blog comments powered by Disqus